# Swarmauri Rag Assistant

## Overview
The Swarmauri Rag Assistant

## Installation
```bash
pip install rag_assistant==0.1.1 --user
```

## Execution
```bash
! rag_assistant --api_key "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" --db_path "E:\\swarmauri_github/prompt_responses.db"
```